@@ -30,8 +30,8 @@
 extern "C" {
 #endif
 
-#define BLKID_VERSION   "2.25.0"
-#define BLKID_DATE      "22-Jul-2014"
+#define BLKID_VERSION   "2.26.0"
+#define BLKID_DATE      "19-Feb-2015"
 
 /**
  * blkid_dev:
