@@ -25,6 +25,7 @@
 #include "closestream.h"
 #include "pathnames.h"
 #include "mountP.h"
+#include "monotonic.h"
 
 /*
  * lock handler
@@ -55,7 +56,8 @@ struct libmnt_lock *mnt_new_lock(const char *datafile, pid_t id)
 	char *lo = NULL, *ln = NULL;
 	size_t losz;
 
-	assert(datafile);
+	if (!datafile)
+		return NULL;
 
 	/* for flock we use "foo.lock, for mtab "foo~"
 	 */
@@ -79,7 +81,7 @@ struct libmnt_lock *mnt_new_lock(const char *datafile, pid_t id)
 	ml->linkfile = ln;
 	ml->lockfile = lo;
 
-	DBG(LOCKS, mnt_debug_h(ml, "alloc: default linkfile=%s, lockfile=%s", ln, lo));
+	DBG(LOCKS, ul_debugobj(ml, "alloc: default linkfile=%s, lockfile=%s", ln, lo));
 	return ml;
 err:
 	free(lo);
@@ -99,7 +101,7 @@ void mnt_free_lock(struct libmnt_lock *ml)
 {
 	if (!ml)
 		return;
-	DBG(LOCKS, mnt_debug_h(ml, "free%s", ml->locked ? " !!! LOCKED !!!" : ""));
+	DBG(LOCKS, ul_debugobj(ml, "free%s", ml->locked ? " !!! LOCKED !!!" : ""));
 	free(ml->lockfile);
 	free(ml->linkfile);
 	free(ml);
@@ -119,7 +121,7 @@ int mnt_lock_block_signals(struct libmnt_lock *ml, int enable)
 {
 	if (!ml)
 		return -EINVAL;
-	DBG(LOCKS, mnt_debug_h(ml, "signals: %s", enable ? "BLOCKED" : "UNBLOCKED"));
+	DBG(LOCKS, ul_debugobj(ml, "signals: %s", enable ? "BLOCKED" : "UNBLOCKED"));
 	ml->sigblock = enable ? 1 : 0;
 	return 0;
 }
@@ -135,7 +137,7 @@ int mnt_lock_use_simplelock(struct libmnt_lock *ml, int enable)
 
 	assert(ml->lockfile);
 
-	DBG(LOCKS, mnt_debug_h(ml, "flock: %s", enable ? "ENABLED" : "DISABLED"));
+	DBG(LOCKS, ul_debugobj(ml, "flock: %s", enable ? "ENABLED" : "DISABLED"));
 	ml->simplelock = enable ? 1 : 0;
 
 	sz = strlen(ml->lockfile);
@@ -155,7 +157,7 @@ int mnt_lock_use_simplelock(struct libmnt_lock *ml, int enable)
 	else if (!ml->simplelock && endswith(ml->lockfile, ".lock"))
 		 memcpy(ml->lockfile + sz - 5, "~", 2);
 
-	DBG(LOCKS, mnt_debug_h(ml, "new lock filename: '%s'", ml->lockfile));
+	DBG(LOCKS, ul_debugobj(ml, "new lock filename: '%s'", ml->lockfile));
 	return 0;
 }
 
@@ -187,7 +189,7 @@ static void unlock_simplelock(struct libmnt_lock *ml)
 	assert(ml->simplelock);
 
 	if (ml->lockfile_fd >= 0) {
-		DBG(LOCKS, mnt_debug_h(ml, "%s: unflocking",
+		DBG(LOCKS, ul_debugobj(ml, "%s: unflocking",
 					mnt_lock_get_lockfile(ml)));
 		close(ml->lockfile_fd);
 	}
@@ -203,7 +205,7 @@ static int lock_simplelock(struct libmnt_lock *ml)
 
 	lfile = mnt_lock_get_lockfile(ml);
 
-	DBG(LOCKS, mnt_debug_h(ml, "%s: locking", lfile));
+	DBG(LOCKS, ul_debugobj(ml, "%s: locking", lfile));
 
 	if (ml->sigblock) {
 		sigset_t sigs;
@@ -258,7 +260,12 @@ static int mnt_wait_mtab_lock(struct libmnt_lock *ml, struct flock *fl, time_t m
 	struct sigaction sa, osa;
 	int ret = 0;
 
-	gettimeofday(&now, NULL);
+	gettime_monotonic(&now);
+	DBG(LOCKS, ul_debugobj(ml, "(%d) waiting for F_SETLKW (now=%lu, maxtime=%lu, diff=%lu)",
+				getpid(),
+				(unsigned long) now.tv_sec,
+				(unsigned long) maxtime,
+				(unsigned long) (maxtime - now.tv_sec)));
 
 	if (now.tv_sec >= maxtime)
 		return 1;		/* timeout */
@@ -270,7 +277,6 @@ static int mnt_wait_mtab_lock(struct libmnt_lock *ml, struct flock *fl, time_t m
 
 	sigaction(SIGALRM, &sa, &osa);
 
-	DBG(LOCKS, mnt_debug_h(ml, "(%d) waiting for F_SETLKW", getpid()));
 
 	alarm(maxtime - now.tv_sec);
 	if (fcntl(ml->lockfile_fd, F_SETLKW, fl) == -1)
@@ -280,7 +286,7 @@ static int mnt_wait_mtab_lock(struct libmnt_lock *ml, struct flock *fl, time_t m
 	/* restore old sigaction */
 	sigaction(SIGALRM, &osa, NULL);
 
-	DBG(LOCKS, mnt_debug_h(ml, "(%d) leaving mnt_wait_setlkw(), rc=%d",
+	DBG(LOCKS, ul_debugobj(ml, "(%d) leaving mnt_wait_setlkw(), rc=%d",
 				getpid(), ret));
 	return ret;
 }
@@ -360,7 +366,7 @@ static void unlock_mtab(struct libmnt_lock *ml)
 		close(ml->lockfile_fd);
 	if (ml->locked && ml->lockfile) {
 		unlink(ml->lockfile);
-		DBG(LOCKS, mnt_debug_h(ml, "unlink %s", ml->lockfile));
+		DBG(LOCKS, ul_debugobj(ml, "unlink %s", ml->lockfile));
 	}
 }
 
@@ -408,7 +414,7 @@ static int lock_mtab(struct libmnt_lock *ml)
 	}
 	close(i);
 
-	gettimeofday(&maxtime, NULL);
+	gettime_monotonic(&maxtime);
 	maxtime.tv_sec += MOUNTLOCK_MAXTIME;
 
 	waittime.tv_sec = 0;
@@ -434,7 +440,7 @@ static int lock_mtab(struct libmnt_lock *ml)
 		if (ml->lockfile_fd < 0) {
 			/* Strange... Maybe the file was just deleted? */
 			int errsv = errno;
-			gettimeofday(&now, NULL);
+			gettime_monotonic(&now);
 			if (errsv == ENOENT && now.tv_sec < maxtime.tv_sec) {
 				ml->locked = 0;
 				continue;
@@ -452,7 +458,7 @@ static int lock_mtab(struct libmnt_lock *ml)
 		if (ml->locked) {
 			/* We made the link. Now claim the lock. */
 			if (fcntl (ml->lockfile_fd, F_SETLK, &flock) == -1) {
-				DBG(LOCKS, mnt_debug_h(ml,
+				DBG(LOCKS, ul_debugobj(ml,
 					"%s: can't F_SETLK lockfile, errno=%d\n",
 					lockfile, errno));
 				/* proceed, since it was us who created the lockfile anyway */
@@ -463,7 +469,7 @@ static int lock_mtab(struct libmnt_lock *ml)
 			int err = mnt_wait_mtab_lock(ml, &flock, maxtime.tv_sec);
 
 			if (err == 1) {
-				DBG(LOCKS, mnt_debug_h(ml,
+				DBG(LOCKS, ul_debugobj(ml,
 					"%s: can't create link: time out (perhaps "
 					"there is a stale lock file?)", lockfile));
 				rc = -ETIMEDOUT;
@@ -478,7 +484,7 @@ static int lock_mtab(struct libmnt_lock *ml)
 			ml->lockfile_fd = -1;
 		}
 	}
-	DBG(LOCKS, mnt_debug_h(ml, "%s: (%d) successfully locked",
+	DBG(LOCKS, ul_debugobj(ml, "%s: (%d) successfully locked",
 					lockfile, getpid()));
 	unlink(linkfile);
 	return 0;
@@ -531,7 +537,7 @@ void mnt_unlock_file(struct libmnt_lock *ml)
 	if (!ml)
 		return;
 
-	DBG(LOCKS, mnt_debug_h(ml, "(%d) %s", getpid(),
+	DBG(LOCKS, ul_debugobj(ml, "(%d) %s", getpid(),
 			ml->locked ? "unlocking" : "cleaning"));
 
 	if (ml->simplelock)
@@ -543,7 +549,7 @@ void mnt_unlock_file(struct libmnt_lock *ml)
 	ml->lockfile_fd = -1;
 
 	if (ml->sigblock) {
-		DBG(LOCKS, mnt_debug_h(ml, "restoring sigmask"));
+		DBG(LOCKS, ul_debugobj(ml, "restoring sigmask"));
 		sigprocmask(SIG_SETMASK, &ml->oldsigmask, NULL);
 	}
 }
@@ -601,7 +607,6 @@ int test_lock(struct libmnt_test *ts, int argc, char *argv[])
 {
 	time_t synctime = 0;
 	unsigned int usecs;
-	struct timeval tv;
 	const char *datafile = NULL;
 	int verbose = 0, loops = 0, l, idx = 1;
 
@@ -646,11 +651,13 @@ int test_lock(struct libmnt_test *ts, int argc, char *argv[])
 
 	/* start the test in exactly defined time */
 	if (synctime) {
+		struct timeval tv;
+
 		gettimeofday(&tv, NULL);
 		if (synctime && synctime - tv.tv_sec > 1) {
 			usecs = ((synctime - tv.tv_sec) * 1000000UL) -
 						(1000000UL - tv.tv_usec);
-			usleep(usecs);
+			xusleep(usecs);
 		}
 	}
 
@@ -676,7 +683,7 @@ int test_lock(struct libmnt_test *ts, int argc, char *argv[])
 		 * concurrent processes happy.
 		 */
 		if (synctime)
-			usleep(25000);
+			xusleep(25000);
 	}
 
 	return 0;
